import { EventEmitter, Component, Input, Output, ViewChild, Pipe, NgModule } from '@angular/core';
import { FormControl, ReactiveFormsModule, FormsModule } from '@angular/forms';
import { MatCheckbox, MatSelectModule, MatInputModule, MatChipsModule, MatIconModule, MatCardModule, MatToolbarModule, MatCheckboxModule, MatDividerModule } from '@angular/material';
import { CommonModule } from '@angular/common';
import { MdePopoverModule } from '@material-extended/mde';

/**
 * @fileoverview added by tsickle
 * Generated from: lib/mat-multiselect.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Multiselect Component which control a patch of screen containing multiselect dropdown control
 */
class MatMultiselectComponent {
    /**
     * Constructor
     */
    constructor() {
        /**
         * Output to parent for selected options
         */
        this.changeSelection = new EventEmitter();
        /**
         * form control for multiselect dropdown
         */
        this.multiSelect = new FormControl();
        /**
         * selected options in dropdown component
         */
        this.selectedOptions = [];
        /**
         * input search text
         */
        this.matSearch = '';
    }
    /**
     * Angular lifecycle event : run once after ngOnChanges
     * @return {?}
     */
    ngOnInit() {
        this.emitValue();
    }
    /**
     * Event for option click in multiselect dropdown
     * @param {?} option selected option in multiselect dropdown
     * @return {?}
     */
    optionClick(option) {
        /** @type {?} */
        const index = this.options.indexOf(option);
        this.options[index].checked = !this.options[index].checked;
        this.emitValue();
    }
    /**
     * Event to emit selected values to parent throgh changeSelection event emmiter
     * @return {?}
     */
    emitValue() {
        this.selectedOptions = this.options.filter((/**
         * @param {?} option
         * @return {?}
         */
        option => option.checked));
        this.multiSelect.patchValue(this.selectedOptions);
        this.evaluateStates();
        this.changeSelection.emit(this.selectedOptions);
    }
    /**
     * Event for changing the state of select all checkbox according to option's state
     * @param {?} value checked value
     * @return {?}
     */
    changeState(value) {
        this.matSearch = '';
        this.options.forEach((/**
         * @param {?} option
         * @return {?}
         */
        option => option.checked = value));
        this.emitValue();
    }
    /**
     * Event for evaluating the state of select all checkbox according to option's state
     * @return {?}
     */
    evaluateStates() {
        this.indeterminate = false;
        if (this.selectedOptions.length === 0 && this.matCheckbox !== undefined) {
            this.matCheckbox.checked = false;
        }
        else if (this.options.length === this.selectedOptions.length && this.matCheckbox !== undefined) {
            this.matCheckbox.checked = true;
        }
        else {
            this.indeterminate = true;
        }
    }
}
MatMultiselectComponent.decorators = [
    { type: Component, args: [{
                selector: 'mat-multiselect',
                template: "<mat-form-field class=\"matSelect\">\r\n    <mat-select [placeholder]=\"data.placeHolder\" [formControl]=\"multiSelect\" multiple>\r\n\r\n        <!-- Mat Select Area -->\r\n        <mat-select-trigger>\r\n            <div class=\"trigger\">\r\n                <mat-chip-list class=\"matChipList\">\r\n                    <mat-chip selected=\"true\" color=\"primary\" [selectable]=\"true\" [removable]=\"true\" (removed)=\"optionClick(selectedOptions[0])\">{{selectedOptions[0]?.value}}\r\n                        <mat-icon matChipRemove>cancel</mat-icon>\r\n                    </mat-chip>\r\n                </mat-chip-list>\r\n\r\n                <span *ngIf=\"selectedOptions?.length > 1\" class=\"countChip\">\r\n          <mat-chip [mdePopoverTriggerFor]=\"appPopover\"\r\n          mdePopoverTriggerOn=\"click\">+{{selectedOptions.length - 1}}</mat-chip>\r\n      </span>\r\n            </div>\r\n        </mat-select-trigger>\r\n\r\n        <!-- Search Input -->\r\n        <mat-form-field *ngIf=\"data.enableSearch\" class=\"matSearch\">\r\n            <input [(ngModel)]='matSearch' matInput placeholder=\"Search\">\r\n        </mat-form-field>\r\n\r\n        <!-- Select All and Clear All -->\r\n        <div class=\"selectclear\" *ngIf=\"data.enableSelectClear\">\r\n            <mat-checkbox #matChekbox [indeterminate]=\"indeterminate\" (change)=\"changeState(matChekbox.checked)\">Select All</mat-checkbox>\r\n            <mat-chip selected=\"true\" [selectable]=\"true\" [removable]=\"true\" (click)=\"changeState(false)\">\r\n                Clear All\r\n                <mat-icon matChipRemove>cancel</mat-icon>\r\n            </mat-chip>\r\n        </div>\r\n        <mat-divider *ngIf=\"data.enableSelectClear\"></mat-divider>\r\n\r\n        <!-- All options belongs ti options -->\r\n        <mat-option *ngFor=\"let option of options | filter:matSearch, let i=index\" (click)=\"optionClick(option)\" [value]=\"option\">{{option.value}}</mat-option>\r\n    </mat-select>\r\n\r\n    <!-- POP-UP for selected options -->\r\n    <mde-popover #appPopover=\"mdePopover\" [mdePopoverOverlapTrigger]=\"false\">\r\n        <mat-card style=\"max-width: 300px\">\r\n            <mat-card-content>\r\n                <mat-chip-list class=\"matChipList\">\r\n                    <mat-chip *ngFor=\"let option of selectedOptions, let i=index\" selected=\"true\" color=\"primary\" [selectable]=\"true\" [removable]=\"true\" (removed)=\"optionClick(option)\">{{option.value}}\r\n                        <mat-icon matChipRemove>cancel</mat-icon>\r\n                    </mat-chip>\r\n                </mat-chip-list>\r\n            </mat-card-content>\r\n        </mat-card>\r\n    </mde-popover>\r\n</mat-form-field>\r\n",
                styles: [".matSearch{margin:10px 0 0 10px}.matSelect{width:500px!important}.matChip{padding:10px;height:100px!important;border-radius:3px}.matChipList{display:inline-block}.countChip{display:inline-block;margin:0 0 0 10px}.trigger{overflow:hidden!important;white-space:nowrap!important;display:inline-block}.selectclear{margin:5px 0 10px 16px}.selectclear mat-chip{float:right;padding:3px 4px 2px 7px!important}"]
            }] }
];
/** @nocollapse */
MatMultiselectComponent.ctorParameters = () => [];
MatMultiselectComponent.propDecorators = {
    data: [{ type: Input }],
    options: [{ type: Input }],
    changeSelection: [{ type: Output }],
    matCheckbox: [{ type: ViewChild, args: [MatCheckbox, { static: false },] }]
};
if (false) {
    /**
     * Input Data to be passed from parent in the following format
     * { placeHolder: 'Locations', enableSelectClear: true, enableSearch: true }
     * @type {?}
     */
    MatMultiselectComponent.prototype.data;
    /**
     * Input Options to be passed from parent in the following format array
     * [ {name: 'ind', value: 'India'} ]
     * @type {?}
     */
    MatMultiselectComponent.prototype.options;
    /**
     * Output to parent for selected options
     * @type {?}
     */
    MatMultiselectComponent.prototype.changeSelection;
    /**
     * Child mat checkbox
     * @type {?}
     */
    MatMultiselectComponent.prototype.matCheckbox;
    /**
     * form control for multiselect dropdown
     * @type {?}
     */
    MatMultiselectComponent.prototype.multiSelect;
    /**
     * selected options in dropdown component
     * @type {?}
     */
    MatMultiselectComponent.prototype.selectedOptions;
    /**
     * indeterminate state od select all checkbox
     * @type {?}
     */
    MatMultiselectComponent.prototype.indeterminate;
    /**
     * input search text
     * @type {?}
     */
    MatMultiselectComponent.prototype.matSearch;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/filter-pipe/filter.pipe.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FilterPipe {
    /**
     * PipeTransform method that returns modified value
     * @param {?} value original options in multiselect
     * @param {?} searchText input text to filter options
     * @return {?} modified multiselect options according to given input text
     */
    transform(value, searchText) {
        return value.filter((/**
         * @param {?} option
         * @return {?}
         */
        option => option.value.toLowerCase().includes(searchText.toLowerCase())));
    }
}
FilterPipe.decorators = [
    { type: Pipe, args: [{
                name: 'filter',
                pure: false
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/mat-multiselect.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Multi Select Module
 */
class MatMultiselectModule {
}
MatMultiselectModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    MatSelectModule,
                    MatInputModule,
                    MatChipsModule,
                    MatIconModule,
                    MatCardModule,
                    MatToolbarModule,
                    MdePopoverModule,
                    ReactiveFormsModule,
                    MatCheckboxModule,
                    MatDividerModule,
                    CommonModule,
                    FormsModule
                ],
                declarations: [MatMultiselectComponent, FilterPipe],
                exports: [MatMultiselectComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: public_api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: mat-multiselect.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { MatMultiselectComponent, MatMultiselectModule, FilterPipe as ɵa };
//# sourceMappingURL=mat-multiselect.js.map
